<!-- Hi there, you wonderful contributor! Please write a description of all the changes of this PR-->

<YOUR DESCRIPTION HERE>


---
- [ ] Check this box when you are sure that you are merging against `develop` (and **not** `master`), or another feature branch.
- [ ] Check this box when you have at least tried compiling BWEnv + one client and run a couple of examples.
